package com.ruoyi.hezhi.mapper;

import com.ruoyi.hezhi.domain.TbConfig;

import java.util.List;
import java.util.Map;

/**
 * 相关设置Mapper接口
 *
 * @author ruoyi
 * @date 2024-10-22
 */
public interface TbConfigMapper
{
    /**
     * 查询相关设置
     *
     * @param configId 相关设置主键
     * @return 相关设置
     */
    public TbConfig selectTbConfigByConfigId(Long configId);

    /**
     * 查询相关设置列表
     *
     * @param tbConfig 相关设置
     * @return 相关设置集合
     */
    public List<TbConfig> selectTbConfigList(TbConfig tbConfig);

    /**
     * 新增相关设置
     *
     * @param tbConfig 相关设置
     * @return 结果
     */
    public int insertTbConfig(TbConfig tbConfig);

    /**
     * 修改相关设置
     *
     * @param tbConfig 相关设置
     * @return 结果
     */
    public int updateTbConfig(TbConfig tbConfig);

    /**
     * 删除相关设置
     *
     * @param configId 相关设置主键
     * @return 结果
     */
    public int deleteTbConfigByConfigId(Long configId);

    /**
     * 批量删除相关设置
     *
     * @param configIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbConfigByConfigIds(Long[] configIds);

    /**
     * 相关设置
     *
     * @param params 参数
     * @return 相关设置详情
     */
    public Map<String, Object> getLiveBroadcastInfo(Map<String, Object> params);

    /**
     * 查询相关设置
     *
     * @param identifying 设置标识
     * @return 相关设置
     */
    public TbConfig selectTbConfigByIdentifying(String identifying);
}
